@@ -28,7 +28,11 @@ class ProgBar(Prog):
     def _adjust_width(self):
         """Shrinks bar if number of iterations is less than the bar width"""
         if self.bar_width > self.max_iter:
-            self.bar_width = self.max_iter
+            self.bar_width = int(self.max_iter) 
+            # some Python 3.3.3 users specifically 
+            # on Linux Red Hat 4.4.7-1, GCC v. 4.4.7
+            # reported that self.max_iter was converted to
+            # float. Thus this fix to prevent float multiplication of chars.
 
     def _init_bar(self):
         """Writes the initial bar frames to the output screen"""
